@@ -7,7 +7,7 @@ import sys
 
 from airbyte_cdk.entrypoint import launch
 
-from .config_migrations import MigrateAccountIdToArray, MigrateIncludeDeletedToStatusFilters
+from .config_migrations import MigrateAccountIdToArray, MigrateIncludeDeletedToStatusFilters, MigrateSecretsPathInConnector
 from .source import SourceFacebookMarketing
 
 
@@ -15,4 +15,5 @@ def run():
     source = SourceFacebookMarketing()
     MigrateAccountIdToArray.migrate(sys.argv[1:], source)
     MigrateIncludeDeletedToStatusFilters.migrate(sys.argv[1:], source)
+    MigrateSecretsPathInConnector.migrate(sys.argv[1:], source)
     launch(source, sys.argv[1:])
