@@ -42,6 +42,16 @@ class AdsInsights(FBMarketingIncrementalStream):
         "action_destination",
     ]
 
+    object_breakdowns = {
+        "body_asset": "body_asset_id",
+        "call_to_action_asset": "call_to_action_asset_id",
+        "description_asset": "description_asset_id",
+        "image_asset": "image_asset_id",
+        "link_url_asset": "link_url_asset_id",
+        "title_asset": "title_asset_id",
+        "video_asset": "video_asset_id",
+    }
+
     # Facebook store metrics maximum of 37 months old. Any time range that
     # older than 37 months from current date would result in 400 Bad request HTTP response.
     # https://developers.facebook.com/docs/marketing-api/reference/ad-account/insights/#overview
@@ -50,6 +60,8 @@ class AdsInsights(FBMarketingIncrementalStream):
     action_attribution_windows = ALL_ACTION_ATTRIBUTION_WINDOWS
     time_increment = 1
 
+    status_field = "effective_status"
+
     def __init__(
         self,
         name: str = None,
@@ -82,6 +94,7 @@ class AdsInsights(FBMarketingIncrementalStream):
         self._insights_lookback_window = insights_lookback_window
         self._insights_job_timeout = insights_job_timeout
         self.level = level
+        self.entity_prefix = level
 
         # state
         self._cursor_values: Optional[Mapping[str, pendulum.Date]] = None  # latest period that was read for each account
@@ -97,7 +110,16 @@ class AdsInsights(FBMarketingIncrementalStream):
     @property
     def primary_key(self) -> Optional[Union[str, List[str], List[List[str]]]]:
         """Build complex PK based on slices and breakdowns"""
-        return ["date_start", "account_id", "ad_id"] + self.breakdowns
+
+        breakdowns_pks = []
+
+        for breakdown in self.breakdowns:
+            if breakdown in self.object_breakdowns.keys():
+                breakdowns_pks.append(self.object_breakdowns[breakdown])
+            else:
+                breakdowns_pks.append(breakdown)
+
+        return ["date_start", "account_id", "ad_id"] + breakdowns_pks
 
     @property
     def insights_lookback_period(self):
@@ -113,9 +135,19 @@ class AdsInsights(FBMarketingIncrementalStream):
     def insights_job_timeout(self):
         return pendulum.duration(minutes=self._insights_job_timeout)
 
+    def _transform_breakdown(self, record: Mapping[str, Any]) -> Mapping[str, Any]:
+        for breakdown in self.breakdowns:
+            if breakdown in self.object_breakdowns.keys():
+                record[self.object_breakdowns[breakdown]] = record[breakdown]["id"]
+        return record
+
     def list_objects(self, params: Mapping[str, Any]) -> Iterable:
         """Because insights has very different read_records we don't need this method anymore"""
 
+    def _add_account_id(self, record: dict[str, Any], account_id: str):
+        if "account_id" not in record:
+            record["account_id"] = account_id
+
     def read_records(
         self,
         sync_mode: SyncMode,
@@ -131,7 +163,8 @@ class AdsInsights(FBMarketingIncrementalStream):
             for obj in job.get_result():
                 data = obj.export_all_data()
                 if self._response_data_is_valid(data):
-                    yield data
+                    self._add_account_id(data, account_id)
+                    yield self._transform_breakdown(data)
         except FacebookBadObjectError as e:
             raise AirbyteTracedException(
                 message=f"API error occurs on Facebook side during job: {job}, wrong (empty) response received with errors: {e} "
@@ -298,7 +331,7 @@ class AdsInsights(FBMarketingIncrementalStream):
 
         :return: the first date to sync
         """
-        today = pendulum.today().date()
+        today = pendulum.today(tz=pendulum.tz.UTC).date()
         oldest_date = today - self.INSIGHTS_RETENTION_PERIOD
 
         start_dates_for_account = {}
@@ -335,6 +368,7 @@ class AdsInsights(FBMarketingIncrementalStream):
             "time_increment": self.time_increment,
             "action_attribution_windows": self.action_attribution_windows,
         }
+        req_params.update(self._filter_all_statuses())
         return req_params
 
     def _state_filter(self, stream_state: Mapping[str, Any]) -> Mapping[str, Any]:
@@ -354,6 +388,11 @@ class AdsInsights(FBMarketingIncrementalStream):
         if self.breakdowns:
             breakdowns_properties = loader.get_schema("ads_insights_breakdowns")["properties"]
             schema["properties"].update({prop: breakdowns_properties[prop] for prop in self.breakdowns})
+            # adding object breakdown id to schema
+            for prop in self.breakdowns:
+                object_breakdown_id = self.object_breakdowns.get(prop)
+                if object_breakdown_id:
+                    schema["properties"].update({object_breakdown_id: breakdowns_properties[object_breakdown_id]})
         return schema
 
     def fields(self, **kwargs) -> List[str]:
@@ -366,4 +405,11 @@ class AdsInsights(FBMarketingIncrementalStream):
 
         schema = ResourceSchemaLoader(package_name_from_class(self.__class__)).get_schema("ads_insights")
         self._fields = list(schema.get("properties", {}).keys())
+
+        # Having this field in syncs seem to have caused data inaccuracy where fields like `spend` had the wrong values
+        try:
+            self._fields.remove("wish_bid")
+        except ValueError:
+            pass
+
         return self._fields
